diff --git a/contrib/pg_stat_statements/pg_stat_statements.c b/contrib/pg_stat_statements/pg_stat_statements.c
index 3da490b66d..8c20c91200 100644
--- a/contrib/pg_stat_statements/pg_stat_statements.c
+++ b/contrib/pg_stat_statements/pg_stat_statements.c
@@ -304,8 +304,8 @@ PG_FUNCTION_INFO_V1(pg_stat_statements);
 static void pgss_shmem_startup(void);
 static void pgss_shmem_shutdown(int code, Datum arg);
 static PlannedStmt *pgss_planner_hook(Query *parse,
-									  int cursorOptions,
-									  ParamListInfo boundParams);
+				  int cursorOptions,
+				  ParamListInfo boundParams);
 static void pgss_post_parse_analyze(ParseState *pstate, Query *query);
 static void pgss_ExecutorStart(QueryDesc *queryDesc, int eflags);
 static void pgss_ExecutorRun(QueryDesc *queryDesc,
@@ -789,19 +789,20 @@ error:
 /*
  * Planner hook: forward to regular planner, but measure planning time.
  */
-static PlannedStmt *pgss_planner_hook(Query *parse,
-									  int cursorOptions,
-									  ParamListInfo boundParams)
+static PlannedStmt *
+pgss_planner_hook(Query *parse,
+				  int cursorOptions,
+				  ParamListInfo boundParams)
 {
 	PlannedStmt *result;
 	BufferUsage bufusage_start,
 				bufusage;
 
-		bufusage_start = pgBufferUsage;
+	bufusage_start = pgBufferUsage;
 	if (pgss_enabled())
 	{
-		instr_time		start;
-		instr_time		duration;
+		instr_time	start;
+		instr_time	duration;
 
 		INSTR_TIME_SET_CURRENT(start);
 
@@ -850,8 +851,8 @@ static PlannedStmt *pgss_planner_hook(Query *parse,
 		bufusage.blk_write_time = pgBufferUsage.blk_write_time;
 		INSTR_TIME_SUBTRACT(bufusage.blk_write_time, bufusage_start.blk_write_time);
 
-				pgss_store("",
-				   parse->queryId,			/* signal that it's a utility stmt */
+		pgss_store("",
+				   parse->queryId,	/* signal that it's a utility stmt */
 				   -1,
 				   0,
 				   0,
@@ -931,15 +932,15 @@ pgss_post_parse_analyze(ParseState *pstate, Query *query)
 	 * the normalized string would be the same as the query text anyway, so
 	 * there's no need for an early entry.
 	 */
-		pgss_store(pstate->p_sourcetext,
-				   query->queryId,
-				   query->stmt_location,
-				   query->stmt_len,
-				   0,
-				   0,
-				   0,
-				   NULL,
-				   &jstate);
+	pgss_store(pstate->p_sourcetext,
+			   query->queryId,
+			   query->stmt_location,
+			   query->stmt_len,
+			   0,
+			   0,
+			   0,
+			   NULL,
+			   &jstate);
 }
 
 /*
@@ -1044,7 +1045,7 @@ pgss_ExecutorEnd(QueryDesc *queryDesc)
 				   queryDesc->plannedstmt->stmt_location,
 				   queryDesc->plannedstmt->stmt_len,
 				   queryDesc->totaltime->total * 1000.0,	/* convert to msec */
-					0,
+				   0,
 				   queryDesc->estate->es_processed,
 				   &queryDesc->totaltime->bufusage,
 				   NULL);
@@ -1255,8 +1256,9 @@ pgss_store(const char *query, uint64 queryId,
 		queryId = pgss_hash_string(query, query_len);
 
 		/*
-		 * If we are unlucky enough to get a hash of zero(invalid), use queryID
-		 * as 2 instead, queryID 1 is already in use for normal statements.
+		 * If we are unlucky enough to get a hash of zero(invalid), use
+		 * queryID as 2 instead, queryID 1 is already in use for normal
+		 * statements.
 		 */
 		if (queryId == UINT64CONST(0))
 			queryId = UINT64CONST(2);
@@ -1355,7 +1357,7 @@ pgss_store(const char *query, uint64 queryId,
 		{
 			e->counters.calls += 1;
 			e->counters.total_time += total_time;
-		}	
+		}
 
 		if (e->counters.calls == 1 && planning_time == 0)
 		{
@@ -1363,7 +1365,7 @@ pgss_store(const char *query, uint64 queryId,
 			e->counters.max_time = total_time;
 			e->counters.mean_time = total_time;
 		}
-		else if(planning_time == 0)
+		else if (planning_time == 0)
 		{
 			/*
 			 * Welford's method for accurately computing variance. See
